==> jackrabbit-oak-1.22.23-src.zip: jackrabbit-oak-1.22.23/oak-auth-external/src/test/java/org/apache/jackrabbit/oak/spi/security/authentication/external/impl/SyncManagerImplTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.oak.spi.security.authentication.external.impl;

import org.apache.jackrabbit.oak.spi.security.authentication.external.SyncHandler;
import org.apache.sling.testing.mock.osgi.junit.OsgiContext;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;

import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertSame;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

public class SyncManagerImplTest {

    @Rule
    public final OsgiContext context = new OsgiContext();

    private SyncManagerImpl syncManager = new SyncManagerImpl();

    @Before()
    public void before() {
        context.registerInjectActivateService(syncManager);
    }

    @Test
    public void testGetHandler() {
        assertNull(syncManager.getSyncHandler("test"));
        assertNull(syncManager.getSyncHandler("another"));

        SyncHandler syncHandler = when(mock(SyncHandler.class).getName()).thenReturn("test").getMock();
        context.registerService(SyncHandler.class, syncHandler);

        assertSame(syncHandler, syncManager.getSyncHandler("test"));
        assertNull(syncManager.getSyncHandler("another"));
    }
}

==> jackrabbit-oak-1.88.0-src.zip: jackrabbit-oak-1.88.0/oak-auth-external/src/test/java/org/apache/jackrabbit/oak/spi/security/authentication/external/impl/SyncManagerImplTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.oak.spi.security.authentication.external.impl;

import org.apache.jackrabbit.oak.spi.security.authentication.external.SyncHandler;
import org.apache.sling.testing.mock.osgi.junit.OsgiContext;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;

import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertSame;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

public class SyncManagerImplTest {

    @Rule
    public final OsgiContext context = new OsgiContext();

    private final SyncManagerImpl syncManager = new SyncManagerImpl();

    @Before()
    public void before() {
        context.registerInjectActivateService(syncManager);
    }

    @Test
    public void testGetHandler() {
        assertNull(syncManager.getSyncHandler("test"));
        assertNull(syncManager.getSyncHandler("another"));

        SyncHandler syncHandler = when(mock(SyncHandler.class).getName()).thenReturn("test").getMock();
        context.registerService(SyncHandler.class, syncHandler);

        assertSame(syncHandler, syncManager.getSyncHandler("test"));
        assertNull(syncManager.getSyncHandler("another"));
    }
}
